@@ -29,9 +29,6 @@ headers = {
 #Constants
 indices = ['NIFTY','NIFTYIT','BANKNIFTY']
 
-def test():
-    print("6.0")
-
 #Getting FNO Symboles
 def fnolist():
     df = pd.read_csv("https://www1.nseindia.com/content/fo/fo_mktlots.csv")
@@ -173,3 +170,38 @@ def nse_fno(symbol):
     except KeyError:
         print("Getting Error While Fetching.")
     return payload
+
+def quote_equity(symbol):
+    return nse_eq(symbol)
+
+def quote_derivative(symbol):
+    return nse_fno(symbol)
+
+def option_chain(symbol):
+    return nse_optionchain_scrapper(symbol)
+
+def nse_holidays(type="trading"):
+    if(type=="clearing"):
+        payload = requests.get('https://www.nseindia.com/api/holiday-master?type=clearing',headers=headers).json()
+    if(type=="trading"):
+        payload = requests.get('https://www.nseindia.com/api/holiday-master?type=trading',headers=headers).json()
+    return payload
+
+def holiday_master(type="trading"):
+    return nse_holidays(type)
+
+def nse_results(index="equities",period="Quarterly"):
+    if(index=="equities") or (index=="debt") or (index=="sme"):
+        if(period=="Quarterly") or (period=="Annual")or (period=="Half-Yearly")or (period=="Others"):
+            payload = requests.get('https://www.nseindia.com/api/corporates-financial-results?index='+index+'&period='+period,headers=headers).json()
+            return pd.json_normalize(payload)
+        else:
+            print("Give Correct Period Input")
+    else:
+        print("Give Correct Index Input")
+
+def nse_events():
+    return pd.json_normalize(requests.get('https://www.nseindia.com/api/event-calendar',headers=headers).json())
+
+def nse_past_results(symbol):
+    return requests.get('https://www.nseindia.com/api/results-comparision?symbol='+symbol.replace('&','%26'),headers=headers).json()
